@@ -9,7 +9,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1335, USA
  */
 
 #include "common.h"
@@ -243,6 +243,8 @@ do_gdImagePngName(int nargs, awk_value_t *result)
 	}
 	if (!(out = fopen(fName.str_value.str, "wb")))
 		RETURN_NOK;
+
+	gdImageSaveAlpha(im, 1);  /* save full alpha channel */
 	gdImagePng(im, out);
 	fclose(out);
 	RETURN_OK;
@@ -667,6 +669,6 @@ init_my_module(void)
 }
 
 static awk_bool_t (*init_func)(void) = init_my_module;
-static const char ext_version[] = "GD extension: version 1.0";
+static const char ext_version[] = PACKAGE_STRING;
 
 dl_load_func(func_table, gd, "")
